absinthe_relay v1.4.6 Absinthe.Relay.Node.Notation View Source
Macros used to define Node-related schema entities
See Absinthe.Relay.Node for examples of use.
Link to this section Summary
Functions
Define a node interface, field, or object type for a schema
Link to this section Functions
Define a node interface, field, or object type for a schema.
See the Absinthe.Relay.Node module documentation for examples.